<?php
/*
 *
 */
namespace FishPig\WordPress\Block\Post\PostList;

/* Parent Block */
use Magento\Theme\Block\Html\Pager as MagentoPager;

/* Constructor Args */
use Magento\Framework\View\Element\Template\Context;
use FishPig\WordPress\Model\OptionManager;
use Magento\Framework\App\Config\ScopeConfigInterface;
class Pager extends MagentoPager
{
	/*
	 * @var OptionManager
	 */
	protected $optionManager;
	
	/*
	 *
	 * @ScopeConfigInterface
	 *
	 */
	protected $scopeConfig;
	
  /*
   * Constructor
   *
   * @param Context $context
   * @param App
   * @param array $data
   */
  public function __construct(Context $context, OptionManager $optionManager, ScopeConfigInterface $scopeConfig, array $data = [])
  {
    $this->optionManager = $optionManager;
    $this->scopeConfig   = $scopeConfig;
    
    parent::__construct($context, $data);
  }

	/**
	 * Construct the pager and set the limits
	 *
	 */
	protected function _construct()
	{
		parent::_construct();	

		$this->setPageVarName('page');

		$baseLimit = $this->optionManager->getOption('posts_per_page', 10);

		$this->setDefaultLimit($baseLimit);
		$this->setLimit($baseLimit);
		$this->setAvailableLimit([$baseLimit => $baseLimit]);

		$this->setFrameLength(
			(int)$this->scopeConfig->getValue(
				'design/pagination/pagination_frame',
				\Magento\Store\Model\ScopeInterface::SCOPE_STORE
			)
		);
	}
	
	/**
	 * Return the URL for a certain page of the collection
	 *
	 * @return string
	 */
	public function getPagerUrl($params = array())
	{
		$pageVarName = $this->getPageVarName();

		if (isset($params[$pageVarName])) {
			$slug = '/' . $pageVarName . '/' . $params[$pageVarName] . '/';
			unset($params[$pageVarName]);
		}
		else {
			$slug = '';
		}
		
		$pagerUrl = parent::getPagerUrl($params);
		
		if (strpos($pagerUrl, '?') !== false) {
			$pagerUrl = rtrim(substr($pagerUrl, 0, strpos($pagerUrl, '?')), '/') . $slug . substr($pagerUrl, strpos($pagerUrl, '?'));
		}
		else {
			$pagerUrl = rtrim($pagerUrl, '/') . $slug;
		}
		
		return $pagerUrl;
	}
}
